# User Guide

This guide will help you get started with Prismo and learn how to use its various features for FDTD simulations of photonic waveguides.

## Getting Started

```{toctree}
:maxdepth: 2

installation
quickstart
```

## Core Concepts

```{toctree}
:maxdepth: 2

simulations
sources_monitors
boundaries
materials
```

## Advanced Features

```{toctree}
:maxdepth: 2

mode_analysis
mode_ports
gpu_acceleration
advanced
```

## Analysis and Output

```{toctree}
:maxdepth: 2

data_export
visualization
validation
```
